DataEngineConfigBuilder

Struct DataEngineConfigBuilder 

pub struct DataEngineConfigBuilder<S: State = Empty> { /* private fields */ }
Use builder syntax to set the inputs and finish with build().

Implementations

Source

impl<S: State> DataEngineConfigBuilder<S>

pub fn build(self) -> DataEngineConfig
where S: IsComplete,

Finish building and return the requested object

pub fn time_bars_build_with_no_updates( self, value: bool, ) -> DataEngineConfigBuilder<SetTimeBarsBuildWithNoUpdates<S>>
where S::TimeBarsBuildWithNoUpdates: IsUnset,

Optional (Some / Option setters). Default: true.

If time bar aggregators will build and emit bars with no new market updates.

pub fn maybe_time_bars_build_with_no_updates( self, value: Option<bool>, ) -> DataEngineConfigBuilder<SetTimeBarsBuildWithNoUpdates<S>>
where S::TimeBarsBuildWithNoUpdates: IsUnset,

Optional (Some / Option setters). Default: true.

If time bar aggregators will build and emit bars with no new market updates.

pub fn time_bars_timestamp_on_close( self, value: bool, ) -> DataEngineConfigBuilder<SetTimeBarsTimestampOnClose<S>>
where S::TimeBarsTimestampOnClose: IsUnset,

Optional (Some / Option setters). Default: true.

If time bar aggregators will timestamp ts_event on bar close. If False, then will timestamp on bar open.

pub fn maybe_time_bars_timestamp_on_close( self, value: Option<bool>, ) -> DataEngineConfigBuilder<SetTimeBarsTimestampOnClose<S>>
where S::TimeBarsTimestampOnClose: IsUnset,

Optional (Some / Option setters). Default: true.

If time bar aggregators will timestamp ts_event on bar close. If False, then will timestamp on bar open.

pub fn time_bars_skip_first_non_full_bar( self, value: bool, ) -> DataEngineConfigBuilder<SetTimeBarsSkipFirstNonFullBar<S>>
where S::TimeBarsSkipFirstNonFullBar: IsUnset,

Optional (Some / Option setters). Default: false.

If time bar aggregators will skip emitting a bar if the aggregation starts mid-interval.

pub fn maybe_time_bars_skip_first_non_full_bar( self, value: Option<bool>, ) -> DataEngineConfigBuilder<SetTimeBarsSkipFirstNonFullBar<S>>
where S::TimeBarsSkipFirstNonFullBar: IsUnset,

Optional (Some / Option setters). Default: false.

If time bar aggregators will skip emitting a bar if the aggregation starts mid-interval.

pub fn time_bars_interval_type( self, value: BarIntervalType, ) -> DataEngineConfigBuilder<SetTimeBarsIntervalType<S>>
where S::TimeBarsIntervalType: IsUnset,

Optional (Some / Option setters). Default: BarIntervalType::LeftOpen.

Determines the type of interval used for time aggregation.

  • LeftOpen: start time is excluded and end time is included (default).
  • RightOpen: start time is included and end time is excluded.
pub fn maybe_time_bars_interval_type( self, value: Option<BarIntervalType>, ) -> DataEngineConfigBuilder<SetTimeBarsIntervalType<S>>
where S::TimeBarsIntervalType: IsUnset,

Optional (Some / Option setters). Default: BarIntervalType::LeftOpen.

Determines the type of interval used for time aggregation.

  • LeftOpen: start time is excluded and end time is included (default).
  • RightOpen: start time is included and end time is excluded.
pub fn time_bars_build_delay( self, value: u64, ) -> DataEngineConfigBuilder<SetTimeBarsBuildDelay<S>>
where S::TimeBarsBuildDelay: IsUnset,

Optional (Some / Option setters). Default: 0.

The time delay (microseconds) before building and emitting a bar.

pub fn maybe_time_bars_build_delay( self, value: Option<u64>, ) -> DataEngineConfigBuilder<SetTimeBarsBuildDelay<S>>
where S::TimeBarsBuildDelay: IsUnset,

Optional (Some / Option setters). Default: 0.

The time delay (microseconds) before building and emitting a bar.

pub fn time_bars_origins( self, value: HashMap<BarAggregation, Duration>, ) -> DataEngineConfigBuilder<SetTimeBarsOrigins<S>>
where S::TimeBarsOrigins: IsUnset,

Optional (Some / Option setters). Default: <HashMap<BarAggregation, Duration> as Default>::default().

A dictionary mapping time bar aggregations to their origin time offsets.

pub fn maybe_time_bars_origins( self, value: Option<HashMap<BarAggregation, Duration>>, ) -> DataEngineConfigBuilder<SetTimeBarsOrigins<S>>
where S::TimeBarsOrigins: IsUnset,

Optional (Some / Option setters). Default: <HashMap<BarAggregation, Duration> as Default>::default().

A dictionary mapping time bar aggregations to their origin time offsets.

pub fn validate_data_sequence( self, value: bool, ) -> DataEngineConfigBuilder<SetValidateDataSequence<S>>
where S::ValidateDataSequence: IsUnset,

Optional (Some / Option setters). Default: false.

If data objects timestamp sequencing will be validated and handled.

pub fn maybe_validate_data_sequence( self, value: Option<bool>, ) -> DataEngineConfigBuilder<SetValidateDataSequence<S>>
where S::ValidateDataSequence: IsUnset,

Optional (Some / Option setters). Default: false.

If data objects timestamp sequencing will be validated and handled.

pub fn buffer_deltas( self, value: bool, ) -> DataEngineConfigBuilder<SetBufferDeltas<S>>
where S::BufferDeltas: IsUnset,

Optional (Some / Option setters). Default: false.

If order book deltas should be buffered until the F_LAST flag is set for a delta.

pub fn maybe_buffer_deltas( self, value: Option<bool>, ) -> DataEngineConfigBuilder<SetBufferDeltas<S>>
where S::BufferDeltas: IsUnset,

Optional (Some / Option setters). Default: false.

If order book deltas should be buffered until the F_LAST flag is set for a delta.

pub fn external_clients( self, value: Vec<ClientId>, ) -> DataEngineConfigBuilder<SetExternalClients<S>>
where S::ExternalClients: IsUnset,

Optional (Some / Option setters). The client IDs declared for external stream processing. The data engine will not attempt to send data commands to these client IDs.

pub fn maybe_external_clients( self, value: Option<Vec<ClientId>>, ) -> DataEngineConfigBuilder<SetExternalClients<S>>
where S::ExternalClients: IsUnset,

Optional (Some / Option setters). The client IDs declared for external stream processing. The data engine will not attempt to send data commands to these client IDs.

pub fn debug(self, value: bool) -> DataEngineConfigBuilder<SetDebug<S>>
where S::Debug: IsUnset,

Optional (Some / Option setters). Default: false.

If debug mode is active (will provide extra debug logging).

pub fn maybe_debug( self, value: Option<bool>, ) -> DataEngineConfigBuilder<SetDebug<S>>
where S::Debug: IsUnset,

Optional (Some / Option setters). Default: false.

If debug mode is active (will provide extra debug logging).